#ifndef NDEMATERIALSTYLE_H
#define NDEMATERIALSTYLE_H

#include <QObject>
#include <QRgb>
#include "ndeglobals.h"
#include <QColor>
#include <QPainter>


namespace Nde
{
NDE_API QColor overlayColors(const QColor &base, const QColor &paint,
                                       QPainter::CompositionMode comp = QPainter::CompositionMode_SourceOver);

NDE_API QColor alphaColor(QColor &base, qreal alpha);

class MaterialStylePrivate;

class NDE_API MaterialStyle : public QObject
{
    Q_OBJECT
public:
    enum Theme {
        Light,
        Dark
    };
    enum ColorSet{
        Primary, // 主色,当前为#2cdfc
        Secondary, //第二颜色,当前为 #011222
        WindowText, // 文字颜色,默认为黑
        Window,  //背景颜色,默认为白
    };
    enum MaskType{
        WhiteMask,
        BlackMask,
        PrimaryMask,
    };

    Q_ENUM(ColorSet)
    Q_ENUM(Theme)
    explicit MaterialStyle(QObject *parent = nullptr);
    void setTheme(Theme theme);
    void createPalette(QPalette &palette);
    QColor brush(ColorSet name, qreal opacity, MaskType type);
    QColor brush(ColorSet name, QColor color);
    QColor brush(ColorSet name, qreal opacity);
private:
    Q_DECLARE_PRIVATE(MaterialStyle)
    MaterialStylePrivate* const d_ptr;
};
}
#endif // NDEMATERIALSTYLE_H
